﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'clipboard', 'sr-latn', {
	copy: 'Kopiraj',
	copyError: 'Sigurnosna podešavanja Vašeg pretraživača ne dozvoljavaju operacije automatskog kopiranja teksta. Molimo Vas da koristite prečicu sa tastature (Ctrl/Cmd+C).',
	cut: 'Iseci',
	cutError: 'Sigurnosna podešavanja Vašeg pretraživača ne dozvoljavaju operacije automatskog isecanja teksta. Molimo Vas da koristite prečicu sa tastature (Ctrl/Cmd+X).',
	paste: 'Zalepi',
	pasteNotification: '"Pritisnite taster %1 za lepljenje. Vaš pretraživač ne dozvoljava lepljenje iz alatne trake ili menia.',
	pasteArea: 'Prostor za lepljenje',
	pasteMsg: 'Nalepite sadržaj u sledeći prostor i pritisnite taster OK.',
	fileFormatNotSupportedNotification: 'Formati datoteke ${formats} nisu podržani.',
	fileWithoutFormatNotSupportedNotification: 'Format datoteke nije podržan.'
} );
